CMD_APP_CREATE = 'create a new app'
OPT_APP_CREATE_DESCRIPTION = 'sets a description for your app'
OPT_APP_CREATE_FRAMEWORK = 'defines which framework your app will be deployed'
OPT_APP_CREATE_POOL = 'defines which pool your app will be deployed to (depracated)'
OPT_APP_CREATE_IGNORE_IF_EXISTS = 'errors will be ignored when creating a resource that already exists'
OPT_APP_CREATE_TEAM = 'describes which team is responsible for the created app'
OPT_APP_CREATE_PLAN = ' parameter defines the plan to be used'
OPT_APP_CREATE_TAG = 'sets a tag to your app. available multiple times'
OPT_APP_CREATE_DEPENDENCY = 'sets inspect file to create app dependencies. available multiple times'
CMD_APP_DEPLOY = 'deploy the source to shipa server'
OPT_APP_DEPLOY_APP = 'specify which app you want to deploy'
OPT_APP_DEPLOY_STEP_INTERVAL = 'single step duration. supported min: m, hour:h, second:s. ex. 1m, 60s, 1h'
OPT_APP_DEPLOY_STEPS = 'steps for canary deployment'
OPT_APP_DEPLOY_DIRECTORY = 'directory to deploy (default .)'
OPT_APP_DEPLOY_IMAGE = 'app image'
OPT_APP_DEPLOY_STEP_WEIGHT = 'deploy step weight'
OPT_APP_DEPLOY_PORT = 'app port (f.e. TCP/8888 or 8888)'
OPT_APP_DEPLOY_REGISTRY_USER = 'username for private registry'
OPT_APP_DEPLOY_REGISTRY_SECRET = 'secret (password) for private registry'
CMD_APP_REMOVE = 'remove a shipa app'
OPT_APP_REMOVE_APP = 'specify which app you want to remove'
CMD_APP_MOVE = 'move a shipa app to another framework'
OPT_APP_MOVE_APP = 'specify which app you want to move'
OPT_APP_MOVE_FRAMEWORK = 'specify which framework you want to move'
CMD_FRAMEWORK_ADD = 'adds a new framework'
OPT_FRAMEWORK_INGRESS = 'ingress controller to use for this framework'
OPT_FRAMEWORK_PUBLIC = 'make framework public (all teams can use it)'
OPT_FRAMEWORK_DEFAULT = 'make framework default (when none is specified during app-create this framework will be used)'
OPT_FRAMEWORK_PROVISIONER = 'provisioner associated to the framework (empty for default docker provisioner)'
OPT_FRAMEWORK_PLAN = 'the plan when adding app to this framework'
OPT_FRAMEWORK_TEAM = 'allowed teams'
OPT_FRAMEWORK_QUOTA_LIMIT = 'quota limit for app when adding it to this framework'
OPT_FRAMEWORK_NAMESPACE = 'kubernetes namespace for this framework'
OPT_FRAMEWORK_DRIVER = 'node drivers accepted in framework. available multiple times'
CMD_FRAMEWORK_REMOVE = 'remove an existing framework.'
CMD_FRAMEWORK_UPDATE = 'updates attributes for a framework.'
CMD_NODE_ADD = 'creates or registers a new node in the cluster'
OPT_NODE_FRAMEWORK = 'framework which will use this node. available multiple times'
OPT_NODE_REGISTER = 'registers an existing docker endpoint, the IaaS won\'t be called.'
OPT_NODE_CA_CERT = 'path to CA file shipa should trust.'
OPT_NODE_CLIENT_CERT = 'path to client TLS certificate file.'
OPT_NODE_CLIENT_KEY = 'path to client TLS key file.'
OPT_NODE_IAAS = 'which iaas provider should be used, if not set shipa will use the default ' \
                'iaas specified in shipa.conf file.'
OPT_NODE_IAASID = 'iaas\'s id.'
OPT_NODE_TEMPLATE = 'A machine template with predefined parameters, additional parameters will override ' \
                    'template ones.'
OPT_NODE_ADDRESS = 'only used if --register option is used. Should point to the endpoint of a working server.'
OPT_NODE_DRIVER = 'which node driver should be used. amazonec2, google, azure, vmwarevsphere, generic, ' \
                  'hyperv, openstack, virtualbox, vmwarefusion'
CMD_NODE_REMOVE = 'removes a node from the cluster'
CMD_NODE_DESTROY = 'destroy node from Iaas'
CMD_NODE_NO_REBALANCE = 'don\'t rebalance containers from removed node'
CMD_CLUSTER_ADD = 'creates a kubernetes cluster definition'
CMD_CLUSTER_ADDRESS = 'address to be used in cluster'
CMD_CLUSTER_TOKEN = 'token used for connection to the cluster'
OPT_CLUSTER_FRAMEWORK = 'framework which will use this cluster'
OPT_CLUSTER_TEAM = 'cluster teams'
OPT_CLUSTER_DEFAULT = 'whether this is the default cluster.'
OPT_CLUSTER_INGRESS_SERVICE = 'specify ingress service type (LoadBalancer/ClusterIP/NodePort)'
OPT_CLUSTER_INGRESS_IP = 'ingress ip address'
OPT_CLUSTER_INGRESS_HTTP_PORT = 'ingress http port'
OPT_CLUSTER_INGRESS_HTTPS_PORT = 'ingress https port'
OPT_CLUSTER_INGRESS_PROTECTED_PORT = 'ingress protected port'
OPT_CLUSTER_INSTALL_CERT_MANAGER = 'install cert manager'
OPT_CLUSTER_CUSTOM = 'KEY=VALUE \n\n' \
                     'custom cluster specific data'
OPT_CLUSTER_PROVISIONER = 'represents a kubernetes cluster'
KUBERNETES_PROVISIONER = 'kubernetes'
OPT_CLUSTER_REMOVE = 'Removes a kubernetes cluster definition'
OPT_ENV_NO_RESTART = 'Sets environment variables without restart the application'
OPT_ENV_APP = 'The name of the app'
OPT_ENV_PRIVATE = 'Private environment variables'
CMD_ENV_UNSET = "Remove environment variables"
CMD_ENV_SET = "Set environment variables"
